Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(880)

Unified Diff: ui/gfx/compositor/layer_delegate.h

Issue 8362006: Reland r107720 - Enable the new layer animation framework. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/gfx/compositor/layer_animator_unittest.cc ('k') | ui/gfx/compositor/layer_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/compositor/layer_delegate.h
diff --git a/ui/gfx/compositor/layer_delegate.h b/ui/gfx/compositor/layer_delegate.h
index 973d12f97448545494eb0b95409c1aeb3ab6b04b..474689e5be61997add1d0b578ac78355eb5e9010 100644
--- a/ui/gfx/compositor/layer_delegate.h
+++ b/ui/gfx/compositor/layer_delegate.h
@@ -14,7 +14,7 @@ class Canvas;
namespace ui {
-class Animation;
+class LayerAnimationSequence;
// A delegate interface implemented by an object that renders to a Layer.
class COMPOSITOR_EXPORT LayerDelegate {
@@ -23,8 +23,8 @@ class COMPOSITOR_EXPORT LayerDelegate {
// clipped to the Layer's invalid rect.
virtual void OnPaintLayer(gfx::Canvas* canvas) = 0;
- // Called when |animation| ends.
- virtual void OnLayerAnimationEnded(const ui::Animation* animation) = 0;
+ // Called when |seq| ends.
+ virtual void OnLayerAnimationEnded(const LayerAnimationSequence* seq) = 0;
protected:
virtual ~LayerDelegate() {}
« no previous file with comments | « ui/gfx/compositor/layer_animator_unittest.cc ('k') | ui/gfx/compositor/layer_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698